@@ -137,9 +137,17 @@ class AcquisitionSearch:
 
         :return: path to acquiring.txt (if found)
         """
+        # check parent directory (usually only the case if the path was manually specified)
         in_current_dir = list(self.data_parent.glob('ACQUIRING.TXT'))
         if len(in_current_dir) > 0:
             return in_current_dir[0]
+        # search top level of subdirectories (most common file location)
+        for subdir in self.newsorted_subdirectories:
+            try:
+                return next(subdir.glob('ACQUIRING.TXT'))
+            except StopIteration:
+                continue
+        # recursively search subdirectories (slow)
         for subdir in self.newsorted_subdirectories:
             try:
                 return next(subdir.glob('**/ACQUIRING.TXT'))
